@@ -49,7 +49,7 @@ def import_module(name: str, pull=True):
         namespace = __import__(f'{_namespace}.{_name}')
         module = getattr(namespace, _name)
     except ModuleNotFoundError as e:
-        if not str(e).endswith(f"'{_namespace}.{_name}'"):
+        if not str(e).endswith(f"'{_namespace}.{_name}'".replace('-', '_')):
             # it is a module import error but not the one that we are trying to import
             raise ModuleNotFoundError(e)
 
@@ -226,6 +226,28 @@ def _get_package_maintainers(package_data: Dict) -> List[Dict]:
     return package_maintainers
 
 
+def _clean_version(version: str) -> str:
+    """Clean package version."""
+    xyz = [v.strip() for v in version.split('.')]
+
+    if len(xyz) == 2:
+        return f'{xyz[0]}.{xyz[1]}.0'
+
+    x, y, z = xyz[:3]
+
+    if z == '0':
+        return f'{x}.{y}.{z}'
+
+    # clean up the developer version
+    try:
+        version = f'{x}.{y}.{int(z)}'
+    except ValueError:
+        # development version like 0.1.dev1+gf910655.d20210207
+        version = f'{x}.{y}.0'
+
+    return version
+
+
 def _get_package_version(package_data: Dict) -> str:
     """Get package version.
 
@@ -233,19 +255,7 @@ def _get_package_version(package_data: Dict) -> str:
     It removes the .dev part and return x.y.z-1 version if it is a dev version.
     """
     version = package_data.get('Version')
-    xyz = version.split('.')
-    if len(xyz) <= 3:
-        return version
-    # clean up the developer version
-    x, y, z = xyz[:3]
-
-    try:
-        version = f'{x}.{y}.{int(z) - 1}'
-    except ValueError:
-        # development version like 0.1.dev1+gf910655.d20210207
-        version = f'{x}.{y}.0'
-
-    return version
+    return _clean_version(version)
 
 
 def _get_package_data(package_name: str) -> Dict:
@@ -288,7 +298,6 @@ def _get_meta_data(module, package_type: str) -> MetaData:
         qb_info[k] = v
 
     metadata = MetaData.parse_obj(qb_info)
-
     return metadata
 
 
